================
Contributing art
================

Are you an artist? The original art from the books is under copyright, and
cannot be used as-is. However, the art was an important part of stimulating my
youthful enthusiasm - so it would be amazing to have new art to accompany the
old text!
